Module common

Module common 

This module provides types, which are used by the semantic and syntactic representations in Marker.

Structs

BodyId
This ID uniquely identifies a body during linting.
CrateId
This ID uniquely identifies a crate during linting.
ExprId
This ID uniquely identifies an expression during linting.
FieldId
This ID uniquely identifies a field inside a struct during linting.
GenericId
This ID uniquely identifies a generic parameter during linting.
ItemId
This ID uniquely identifies an item during linting.
MacroId
This ID uniquely identifies a macro during linting.
StmtId
This ID uniquely identifies a statement during linting.
TyDefId
This ID uniquely identifies a user defined type during linting.
VarId
This ID uniquely identifies a variable during linting.
VariantId
This ID uniquely identifies an enum variant during linting.

Enums

Abi
Constness
Edition
Level
Setting for how to handle a lint.
MacroReport
FIXME(xFrednet): These settings should be working now, but are still limited due to the limited Span implementation. Ideally, I would also like more options, like a Local variant that only lints in local marcos. For libraries it might also be cool to have a Crate variant, that only lints in user code and code from macros from the specified crate.
Mutability
NodeId
NumKind
Safety
Syncness
TextKind

Traits

HasNodeId