Struct marker_api::common::ExprId
source · #[repr(C)]pub struct ExprId { /* private fields */ }Expand description
This ID uniquely identifies an expression during linting.
Stability notice:
- The ID is not stable between different sessions.
- IDs should never be stored by lint crates, as drivers might change
IDs between different
check_*function calls. - The layout and size of this type might change. The ID will continue to provide the current trait implementations.