Module marker_api::context
source · Expand description
This module is responsible for the MarkerContext struct and related plumbing.
Items in this module are generally unstable, with the exception of the
exposed interface of MarkerContext.
Checkout the documentation of marker_adapter::context for an explanation
of how the backend of these structs is implemented.
Structs
- A map, which allows the request of AST nodes by their ids. An instance of this map can be accessed from
MarkerContext::ast. - This context will be passed to each
LintPasscall to enable the user to emit lints and to retrieve nodes by the given ids.